@@ -5,7 +5,6 @@ from groundx.apis.tags.documents_api import DocumentsApi
 from groundx.apis.tags.search_api import SearchApi
 from groundx.apis.tags.projects_api import ProjectsApi
 from groundx.apis.tags.buckets_api import BucketsApi
-from groundx.apis.tags.api_keys_api import APIKeysApi
 
 TagToApi = typing_extensions.TypedDict(
     'TagToApi',
@@ -14,7 +13,6 @@ TagToApi = typing_extensions.TypedDict(
         TagValues.SEARCH: SearchApi,
         TagValues.PROJECTS: ProjectsApi,
         TagValues.BUCKETS: BucketsApi,
-        TagValues.API_KEYS: APIKeysApi,
     }
 )
 
@@ -24,6 +22,5 @@ tag_to_api = TagToApi(
         TagValues.SEARCH: SearchApi,
         TagValues.PROJECTS: ProjectsApi,
         TagValues.BUCKETS: BucketsApi,
-        TagValues.API_KEYS: APIKeysApi,
     }
 )
