@@ -32,11 +32,9 @@ import frozendict  # noqa: F401
 
 from groundx import schemas  # noqa: F401
 
-from groundx.model.bucket_detail import BucketDetail as BucketDetailSchema
 from groundx.model.bucket_response import BucketResponse as BucketResponseSchema
 
 from groundx.type.bucket_response import BucketResponse
-from groundx.type.bucket_detail import BucketDetail
 
 from . import path
 
@@ -149,9 +147,10 @@ class BaseApi(api_client.Api):
         self,
             path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         stream: bool = False,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -199,6 +198,7 @@ class BaseApi(api_client.Api):
             headers=_headers,
             auth_settings=_auth,
             timeout=timeout,
+            **kwargs
         )
     
         if stream:
@@ -259,7 +259,7 @@ class BaseApi(api_client.Api):
         self,
             path_params: typing.Optional[dict] = {},
         skip_deserialization: bool = True,
-        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
+        timeout: typing.Optional[typing.Union[float, typing.Tuple]] = None,
         accept_content_types: typing.Tuple[str] = _all_accept_content_types,
         stream: bool = False,
     ) -> typing.Union[
@@ -340,6 +340,7 @@ class Get(BaseApi):
     async def aget(
         self,
         bucket_id: int,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -350,6 +351,7 @@ class Get(BaseApi):
         )
         return await self._aget_oapg(
             path_params=args.path,
+            **kwargs,
         )
     
     def get(
@@ -372,6 +374,7 @@ class ApiForget(BaseApi):
     async def aget(
         self,
         bucket_id: int,
+        **kwargs,
     ) -> typing.Union[
         ApiResponseFor200Async,
         api_client.ApiResponseWithoutDeserializationAsync,
@@ -382,6 +385,7 @@ class ApiForget(BaseApi):
         )
         return await self._aget_oapg(
             path_params=args.path,
+            **kwargs,
         )
     
     def get(
